Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2989)

Unified Diff: base/test/android/javatests/src/org/chromium/base/test/util/RenderTest.java

Issue 2114963002: Create Java infrastructure for UI Render Tests. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/test/android/javatests/src/org/chromium/base/test/util/RenderTest.java
diff --git a/base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java b/base/test/android/javatests/src/org/chromium/base/test/util/RenderTest.java
similarity index 57%
copy from base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
copy to base/test/android/javatests/src/org/chromium/base/test/util/RenderTest.java
index 83f8e9f43d3386dbb6457ac578e0dbf8427a6498..a73eb041a1f23ee6efe3f8998913d3a07bb03fd5 100644
--- a/base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
+++ b/base/test/android/javatests/src/org/chromium/base/test/util/RenderTest.java
@@ -10,13 +10,13 @@ import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
* This annotation is for flaky tests.
* <p>
- * Tests with this annotation will not be run on any of the normal bots.
- * Please note that they might eventually run on a special bot.
+ * Tests with this annotation will produce images (renders of Views) that will be compared
+ * against comparison images stored in the repo stored in the directory specified.
*/
-@Target({ElementType.METHOD, ElementType.TYPE})
+@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
-public @interface FlakyTest {
- String message() default "";
-}
+public @interface RenderTest {
+ String goldenFolder() default "";
+}

Powered by Google App Engine
This is Rietveld 408576698
@@ -10,13 +10,13 @@ import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
- * This annotation is for flaky tests.
+ * This annotation is for render tests.
* <p>